SystemOrganization addCategory: #'Magma-Squeak-Client-Application'!
SystemOrganization addCategory: #'Magma-Squeak-Client-UI'!

!FlapTab methodsFor: '*magma-squeak-client' stamp: 'cmm 8/25/2011 23:35'!
isImmutableInMagma
	^ self maUsesStandardStorage not! !

!ReadOnlyVariableBinding methodsFor: '*magma-squeak-client' stamp: 'cmm 12/17/2011 17:43'!
isImmutableInMagma 
	^ true! !

MaSingleton subclass: #MagmaWorld
	instanceVariableNames: 'domainVersion'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma-Squeak-Client-Application'!

!MagmaWorld class methodsFor: 'connect' stamp: 'cmm 9/11/2011 20:44'!
connectTo: aMagmaLocation 
	self current: (aMagmaLocation newSession user: (MagmaUser id: self userName)) root! !

!MagmaWorld class methodsFor: 'connect' stamp: 'cmm 9/11/2011 20:38'!
connectTo: hostname port: port 
	"Connect to the running Magma-Server over TCP/IP."
	self connectTo:
		(MagmaRemoteLocation
			host: hostname
			port: port)! !

!MagmaWorld class methodsFor: 'connect' stamp: 'cmm 1/5/2012 22:18'!
connectToPath: pathName 
	"Connect directly to local Magma database files in single-user mode."
	self connectTo: pathName asMagmaLocalLocation! !

!MagmaWorld class methodsFor: 'create' stamp: 'cmm 9/11/2011 20:22'!
createWorldNamed: aString 
	"After using this method to create the application 'World', start up a Magma-Server on it in a separate image.  Then multiple instances of this image may use my connect methods to connect and collaborate in this world."
	MagmaRepositoryController
		create: aString
		root: self new! !

!MagmaWorld class methodsFor: 'overriding' stamp: 'cmm 1/7/2012 16:31'!
current: aMagmaWorld 
	super current: aMagmaWorld.
	MorphicProject current dockingBar:
		(aMagmaWorld
			ifNil: [ TheWorldMainDockingBar new ]
			ifNotNil: [ self menuClass new ])! !

!MagmaWorld class methodsFor: 'accessing' stamp: 'cmm 8/7/2014 17:00'!
domainVersion
	"Subclasses override."
	^ nil! !

!MagmaWorld class methodsFor: 'maui support' stamp: 'cmm 1/5/2012 22:42'!
mauiConnectWorld
	MaObject hasMaui ifTrue:
		[ ((Smalltalk classNamed: #MauiWorld) current family
			newViewNamed: 'Connect'
			for: self)
			 position: 5 @ 15 ;
			 openInWorld ]! !

!MagmaWorld class methodsFor: 'maui support' stamp: 'cmm 1/5/2012 22:29'!
mauiDefaultView
	^ 'Connect'! !

!MagmaWorld class methodsFor: 'overridden' stamp: 'cmm 9/11/2011 20:46'!
menuClass
	"Applications provide thier own subclass of MagmaWorldMainDockingBar."
	^ TheWorldMainDockingBar! !

!MagmaWorld class methodsFor: 'initialize-release' stamp: 'cmm 1/7/2012 16:36'!
refresh
	self current ifNotNil:
		[ self current magmaSession ifNotNil:
			[ : sess | sess disconnectAndClose ] ].
	self current: self new! !

!MagmaWorld class methodsFor: 'overridden' stamp: 'cmm 9/11/2011 20:44'!
userName
	^ Utilities authorName! !

!MagmaWorld methodsFor: 'accessing' stamp: 'cmm 9/6/2012 11:54'!
domainVersion
	"The MC version number for when this domain last changed its shape to a degree that requires legacy models to apply a conversion utility."
	^ domainVersion! !

!MagmaWorld methodsFor: 'accessing' stamp: 'cmm 9/6/2012 11:54'!
domainVersion: mcVersionNumber
	"The MC version number for when this domain last changed its shape to a degree that requires legacy models to apply a conversion utility."
	domainVersion := mcVersionNumber! !

!MagmaWorld methodsFor: 'private' stamp: 'cmm 8/7/2014 17:03'!
validateDomainVersion
	^ self domainVersion = self class domainVersion ifFalse: [ MagmaUserError signal: 'This repository is version ' , self domainVersion asString , ' but you are running version ' , self class domainVersion , ' of the code.  Please disconnect immediately and run the upgrade utility.' ]! !

TheWorldMainDockingBar subclass: #MagmaWorldMainDockingBar
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma-Squeak-Client-UI'!

!MagmaWorldMainDockingBar methodsFor: 'overridden' stamp: 'cmm 1/5/2012 21:25'!
applicationMenuOn: aDockingBarMenuMorph
	"Subclasses add their custom menus to aDockingBarMenuMorph."! !

!MagmaWorldMainDockingBar methodsFor: 'accessing' stamp: 'cmm 9/11/2011 20:57'!
applicationName
	self subclassResponsibility! !

!MagmaWorldMainDockingBar methodsFor: 'file menu' stamp: 'cmm 1/7/2012 16:28'!
connectToWorldMenuItemOn: menu
	menu addItem: [ :item |
		item
			contents: 'Connect...' translated;
			help: 'Connect to another World...' translated;
			icon: MenuIcons smallObjectsIcon ;
			target: self worldClass ;
			selector: #mauiConnectWorld ]! !

!MagmaWorldMainDockingBar methodsFor: 'app menu' stamp: 'cmm 9/11/2011 22:40'!
exitWorldMenuItemOn: aDockingBarMenuMorph 
	aDockingBarMenuMorph
		 addLine ;
		 addItem:
			[ : item | item
				 contents: 'IDE' translated ;
				 help: 'Remove the application menu -- for further development.' translated ;
				 target: self worldClass ;
				 selector: #reset ]! !

!MagmaWorldMainDockingBar methodsFor: 'file menu' stamp: 'cmm 1/7/2012 16:38'!
fileMenuOn: aDockingBar 
	"Same as super, except removes the 'Save as new version' option."
	aDockingBar addItem:
		[ : item | item
			 contents: 'File' ;
			 addSubMenu:
			[ : menu | 
			self newWorldMenuItemOn: menu.
			MaObject hasMaui ifTrue:
				[ self connectToWorldMenuItemOn: menu.
				menu addLine ].
			self
				 saveMenuItemOn: menu ;
				 saveAsMenuItemOn: menu.
			menu addLine.
			self
				 saveAndQuitMenuItemOn: menu ;
				 quitMenuItemOn: menu ] ]! !

!MagmaWorldMainDockingBar methodsFor: 'help menu' stamp: 'cmm 9/11/2011 21:19'!
helpMenuOn: aDockingBarMenuMorph 
	aDockingBarMenuMorph addItem:
		[ : item | item
			 contents: 'Help' translated ;
			 addSubMenu: [ : menu |  self helpSubmenuOn: menu ] ]! !

!MagmaWorldMainDockingBar methodsFor: 'overridden' stamp: 'cmm 9/11/2011 21:40'!
helpSubmenuOn: aDockingBarMenuMorph
	"Subclasses override as desired."! !

!MagmaWorldMainDockingBar methodsFor: 'construction' stamp: 'cmm 1/7/2012 16:23'!
menusOn: aDockingBarMorph 
	| appMenu |
	appMenu := self
		 fileMenuOn: aDockingBarMorph ;
		 applicationMenuOn: aDockingBarMorph.
	self
		 exitWorldMenuItemOn: appMenu ;
		 helpMenuOn: aDockingBarMorph! !

!MagmaWorldMainDockingBar methodsFor: 'file menu' stamp: 'cmm 1/7/2012 16:48'!
newWorldMenuItemOn: menu 
	menu addItem:
		[ : item | item
			 contents: 'New World' translated ;
			 help: 'Leave this world and start in a new world.' translated ;
			 icon: MenuIcons smallSaveIcon ;
			 target: self ;
			 selector: #resetWorld ]! !

!MagmaWorldMainDockingBar methodsFor: 'file menu' stamp: 'cmm 9/11/2011 20:49'!
quitMenuItemOn: menu
	menu addItem: [ :item |
		item
			contents: 'Quit' translated;
			help: 'Quit back to OS' translated;
			icon: MenuIcons smallQuitIcon;
			target: self;
			selector: #quitSqueak ]! !

!MagmaWorldMainDockingBar methodsFor: 'file menu' stamp: 'cmm 1/7/2012 16:49'!
resetWorld
	(UIManager confirm: 'Are you sure you want to leave this world and start with a new, empty world?') ifTrue: [ self worldClass refresh ]! !

!MagmaWorldMainDockingBar methodsFor: 'file menu' stamp: 'cmm 7/24/2011 15:10'!
saveAndQuitMenuItemOn: menu

	menu addItem: [ :item |
		item
			contents: 'Save And Quit' translated;
			help: 'Save the current state of the desktop on disk, then quit.' translated;
			icon: MenuIcons smallQuitIcon;
			target: self;
			selector: #saveAndQuitSqueak ]! !

!MagmaWorldMainDockingBar methodsFor: 'file menu' stamp: 'cmm 7/24/2011 15:10'!
saveAsMenuItemOn: menu

	menu addItem: [ :item |	
		item
			contents: 'Save As...' translated;
			help: 'Save the current state of desktop on disk under a new name' translated;
			icon: MenuIcons smallSaveAsIcon;
			target: self;
			selector: #saveImageAs ]! !

!MagmaWorldMainDockingBar methodsFor: 'file menu' stamp: 'cmm 7/24/2011 15:10'!
saveMenuItemOn: menu

	menu addItem: [ :item |
		item
			contents: 'Save' translated;
			help: 'Save the current state of the desktop on disk' translated;
			icon: MenuIcons smallSaveIcon;
			target: self;
			selector: #saveImage ]! !

!MagmaWorldMainDockingBar methodsFor: 'overridden' stamp: 'cmm 9/11/2011 21:02'!
worldClass
	"Answer the subclass of MagmaWorld which goes with this menu."
	^ MagmaWorld! !

!TextLineInterval methodsFor: '*magma-squeak-client' stamp: 'cmm 11/26/2011 16:21'!
isImmutableInMagma
	^ false! !
